doapfiend

Package doapfiend |
[hide private]
[frames] | no frames]

# Package doapfiend

source code

# doapfiend

http://trac.doapspace.org/doapfiend

## Description

doapfiend is a command-line client and library for querying, creating and displaying DOAP (Description of a Project) RDF profiles.

doapfiend uses RDFAlchemy and rdflib to parse and serialize DOAP.

## Plugins

Plugins can be written for editing DOAP, scraping websites and creating DOAP, searching for DOAP in SPARQL endpoints, displaying DOAP in various formats such as HTML etc.

Version: 0.3.1

Author: Rob Cakebread <rob@doapspace.org>

Copyright: (C) 2007-2008 Rob Cakebread

License: BSD-2

Submodules | [hide private]
doapfiend.cli: Command-line tool for querying, serializing and displaying DOAP doapfiend.doaplib: Library for parsing, displaying, querying and serializing DOAP doapfiend.lexers: Lexers for semantic web languages. doapfiend.model: Model of a DOAP profile using RDFAlchemy doapfiend.plugins: doapfiend supports setuptools_ entry point plugins. doapfiend.plugins.base: All plugins should inherit doapfiend.plugins.Plugin doapfiend.plugins.fields: This plugin outputs DOAP in human-readable plain text doapfiend.plugins.freshmeat: Currently this plugin uses http://doapspace.org/ to fetch DOAP for Freshmeat doapfiend.plugins.homepage: Fetches DOAP by searching doapspace.org by a project's homepage. doapfiend.plugins.n3: This is a plugin for formatting DOAP output as N3 (Notation 3) syntax. doapfiend.plugins.ohloh: This plugin uses http://rdfohloh.wikier.org/ to fetch DOAP for projects listed on Ohlohh. doapfiend.plugins.pkg_index: Plugin helper to fetch a single DOAP file from doapspace.org by Package Index doapfiend.plugins.pypi: Currently this plugin uses http://doapspace.org/ to fetch DOAP for PyPI (The Python Package Index) doapfiend.plugins.sourceforge: Currently this plugin uses http://doapspace.org/ to fetch DOAP for SourceForge doapfiend.plugins.text: This plugin outputs DOAP in human-readable plain text doapfiend.plugins.url: This plugin loads DOAP by its URL or path to a filename. doapfiend.plugins.xml: This plugin outputs DOAP in RDF/XML It basically does nothing because all DOAP today is in RDF/XML. doapfiend.utils: General purpose helper functions and classes for doapfiend You'll probably want to use doaplib for most cases.

Variables | [hide private]
| log = `logging.getLogger()`